"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emailProviderDefaults = emailProviderDefaults;
exports.phoneProviderDefaults = phoneProviderDefaults;
exports.connectionDefaults = connectionDefaults;
exports.logStreamDefaults = logStreamDefaults;
const utils_1 = require("../tools/utils");
// eslint-disable-next-line import/prefer-default-export
function emailProviderDefaults(emailProvider) {
    // eslint-disable-line
    const updated = Object.assign({}, emailProvider);
    const apiKeyProviders = ['mailgun', 'mandrill', 'sendgrid', 'sparkpost'];
    // Add placeholder for credentials as they cannot be exported
    const { name } = updated;
    if (apiKeyProviders.includes(name)) {
        updated.credentials = Object.assign({ api_key: `##${name.toUpperCase()}_API_KEY##` }, (updated.credentials || {}));
    }
    if (name === 'smtp') {
        // This is to mask smtp_user to '##SMTP_USER##'
        if (updated.credentials && 'smtp_user' in updated.credentials) {
            delete updated.credentials.smtp_user;
        }
        updated.credentials = Object.assign({ smtp_host: '##SMTP_HOSTNAME##', smtp_port: '##SMTP_PORT##', smtp_user: '##SMTP_USER##', smtp_pass: '##SMTP_PASS##' }, (updated.credentials || {}));
    }
    if (name === 'ses') {
        updated.credentials = Object.assign({ accessKeyId: '##SES_ACCESS_KEY_ID##', secretAccessKey: '##SES_ACCESS_SECRET_KEY##', region: '##SES_AWS_REGION##' }, (updated.credentials || {}));
    }
    if (name === 'azure_cs') {
        updated.credentials = Object.assign({ connectionString: '##AZURE_CS_CONNECTION_KEY##' }, (updated.credentials || {}));
    }
    if (name === 'ms365') {
        updated.credentials = Object.assign({ tenantId: '##MS365_TENANT_ID##', clientId: '##MS365_CLIENT_ID##', clientSecret: '##MS365_CLIENT_SECRET##' }, (updated.credentials || {}));
    }
    return updated;
}
function phoneProviderDefaults(phoneProvider) {
    const updated = Object.assign({}, phoneProvider);
    const removeKeysFromOutput = [
        'id',
        'created_at',
        'updated_at',
        'channel',
        'tenant',
        'credentials',
    ];
    removeKeysFromOutput.forEach((key) => {
        if (key in updated) {
            delete updated[key];
        }
    });
    const apiKeyProviders = ['twilio'];
    // Add placeholder for credentials as they cannot be exported
    const { name } = updated;
    if (apiKeyProviders.includes(name)) {
        updated.credentials = {
            auth_token: `##${name.toUpperCase()}_AUTH_TOKEN##`,
        };
    }
    return updated;
}
function connectionDefaults(connection) {
    if (connection.options) {
        // Mask secret for key: connection.options.client_secret
        (0, utils_1.maskSecretAtPath)({
            resourceTypeName: 'connections',
            maskedKeyName: connection.strategy,
            maskOnObj: connection.options,
            keyJsonPath: 'client_secret',
        });
    }
    return connection;
}
function logStreamDefaults(logStreams) {
    // masked sensitive fields
    const sensitiveKeys = [
        'httpAuthorization',
        'splunkToken',
        'datadogApiKey',
        'mixpanelServiceAccountPassword',
        'segmentWriteKey',
    ];
    const maskedLogStreams = logStreams.map((logStream) => {
        if (logStream.sink) {
            sensitiveKeys.forEach((key) => {
                if (logStream.sink && logStream.sink[key]) {
                    (0, utils_1.maskSecretAtPath)({
                        resourceTypeName: 'logStreams',
                        maskedKeyName: logStream.type,
                        maskOnObj: logStream.sink,
                        keyJsonPath: key,
                    });
                }
            });
        }
        return logStream;
    });
    return maskedLogStreams;
}
//# sourceMappingURL=defaults.js.map